/*
 In-line Network Cable Tracer (INCT)
 Version: 0.1
 Author: Alex from insideGadgets (http://www.insidegadgets.com)
 Created: 22/04/2013
 Last Modified: 25/04/2013
 
 Connect 2x INCT to each end of your network cable.
 When the button is held down for 1-2 seconds, the 3V battery with 47 Ohm resistor connects to RX- and RX+ and the 2x INCT
 will pick up this signal and the LED will stay on for 1 seconds
 
 */

#define F_CPU 1000000 // 1 MHz

#define OutPin PB4
#define Mosfet PB2

#include <avr/io.h>
#include <avr/interrupt.h>
#include <avr/sleep.h>
#include <math.h>
#include <util/delay.h>
#include "setup.c"

// ATtiny25/45/85 Pin map
//
//              +-\/-+
//  Reset PB5  1|o   |8  VCC
//        PB3  2|    |7  PB2 Mosfet
//    LED PB4  3|    |6  PB1 AIN1 (negative) RX- on RJ45 Pin 6
//        GND  4|    |5  PB0 AIN0 (positive) RX+ on RJ45 Pin 3
//              +----+

int main(void) {
	setup();
	
	while(1) {
		watchdogSleep(T1S); // Sleep for 1 second
		PORTB |= (1<<Mosfet); // Turn on the Mosfet so we allow RX- to connect to PB1
		
		int compare_high = 0;
		for (int x = 0; x < 100; x++) { // Read the analog comparator VCO a few times
			if (ACSR & (1<<ACO)) {
				compare_high++; // Cable is disconnected or the button to trace has been pressed
				if (compare_high >= 20) {
					break;
				}
			}
		}
		PORTB &= ~(1<<Mosfet);
		
		// If compare was high, turn on the LED and sleep for 1 second
		if (compare_high >= 20) {
			PORTB |= (1<<OutPin);
			watchdogSleep(T1S);
		}
		else {
			PORTB &= ~(1<<OutPin);
		}
	}
}

// Watchdog timer
ISR(WDT_vect) { }
